@@ -5,7 +5,7 @@
 import json
 import platform
 import sys
-from collections import namedtuple
+from collections import OrderedDict, namedtuple
 from typing import Dict, List, Mapping, Optional, Sequence, Tuple, Union, cast
 
 import pkg_resources
@@ -106,23 +106,33 @@ def _dumps_json(envinfo: Dict[str, str]) -> str:
 
 
 def dumps(
-    packages: Optional[Sequence[str]] = None, format: Optional[str] = None, verbosity_level: int = 0
+    packages: Optional[Sequence[str]] = None,
+    format: Optional[str] = None,
+    additional_envinfo: Optional[Mapping[str, str]] = None,
+    verbosity_level: int = 0,
 ) -> str:
-    envinfo = get_envinfo(packages, verbosity_level=verbosity_level)
+    envinfo: Dict[str, str] = OrderedDict()
 
+    if additional_envinfo is not None:
+        envinfo.update(additional_envinfo)
+
+    envinfo.update(get_envinfo(packages, verbosity_level=verbosity_level))
+
+    format_name = ""
     if format:
-        format_name = format.strip().lower()
-        if format_name == "markdown":
-            try:
-                return _dumps_markdown(envinfo)
-            except ImportError:
-                print(
-                    "required modules not installed. try to install dependencies with:\n"
-                    "    pip install envinfopy[markdown]\n",
-                    file=sys.stderr,
-                )
-        elif format_name == "json":
-            return _dumps_json(envinfo)
+        format_name = format.strip().casefold()
+
+    if format_name == "markdown":
+        try:
+            return _dumps_markdown(envinfo)
+        except ImportError:
+            print(
+                "required modules not installed. try to install dependencies with:\n"
+                "    pip install envinfopy[markdown]\n",
+                file=sys.stderr,
+            )
+    elif format_name == "json":
+        return _dumps_json(envinfo)
 
     basic_envinfo = _pop_basic_envinfo(envinfo)
     lines = [
@@ -131,4 +141,7 @@ def dumps(
     ]
     lines.extend([f"{key} version: {value}" for key, value in envinfo.items()])
 
+    if format_name == "itemize":
+        return "\n".join(f"- {line}" for line in lines)
+
     return "\n".join(lines)
