@@ -26,11 +26,11 @@ def parse_option() -> argparse.Namespace:
     parser.add_argument(
         "packages",
         nargs="+",
-        help="packages to extract versions",
+        help="package names to extract versions",
     )
     parser.add_argument(
         "--format",
-        choices=["text", "markdown", "json"],
+        choices=["text", "markdown", "json", "itemize"],
         default="text",
         help="output format",
     )
